==> media_qualtrics-1.0.0.tar.gz: media_qualtrics/js/qualtrics-controller.js <==
((Drupal, once) => {

  /**
   * Listens to Qualtrics message and adapts height accordingly.
   */
  function qualtrics_init() {
    // Listen to the 'sendingSurveyHeight' event to understand how tall the given survey is
    // Note: This API is NOT public and thus is subject to change
    window.addEventListener("message", function (event) {
      try {
        var messageObject = JSON.parse(event.data);

        if (!messageObject || messageObject.from !== 'JFE' || messageObject.to !== 'SI' || messageObject.event !== 'sendingSurveyHeight' && !(typeof messageObject.value === 'string' && messageObject.value.match(/^\d+(\.\d+)?(px)$/))) {
          return;
        }

        var surveyHeight = parseInt(messageObject.value);

        // Find the corresponding iframe.
        var iframes = document.querySelectorAll('iframe');
        for (var i = 0; i < iframes.length; i++) {
          if (iframes[i].contentWindow === event.source) {
            // Change the height of the iframe according to the
            // height communicated plus a buffer since the height received
            // it's too short.
            iframes[i].style.height = surveyHeight + 40 + 'px';
            break;
          }
        }
      } catch (ex) {
        // Swallow exception
      }
    }
    );
  }

  /**
   * Initializes the listener.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attach context and settings for Qualtrics.
   */
  Drupal.behaviors.qualtrics_controller = {
    attach(context) {
      once("qualtrics_controller", "html").forEach((element) => {
        qualtrics_init();
      });
    },
  };
})(Drupal, once);

==> media_qualtrics-1.0.3.tar.gz: media_qualtrics/js/qualtrics-controller.js <==
((Drupal, once) => {

  /**
   * Listens to Qualtrics message and adapts height accordingly.
   */
  function qualtrics_init() {
    // Listen to the 'sendingSurveyHeight' event to understand how tall the given survey is
    // Note: This API is NOT public and thus is subject to change
    window.addEventListener("message", function (event) {
      try {
        var messageObject = JSON.parse(event.data);

        if (!messageObject || messageObject.from !== 'JFE' || messageObject.to !== 'SI' || messageObject.event !== 'sendingSurveyHeight' && !(typeof messageObject.value === 'string' && messageObject.value.match(/^\d+(\.\d+)?(px)$/))) {
          return;
        }

        var surveyHeight = parseInt(messageObject.value);

        // Find the corresponding iframe.
        var iframes = document.querySelectorAll('iframe');
        for (var i = 0; i < iframes.length; i++) {
          if (iframes[i].contentWindow === event.source && iframes[i].classList.contains('qualtrics-embed-container')) {
            // Change the height of the iframe according to the
            // height communicated plus a buffer since the height received
            // it's too short.
            iframes[i].style.height = surveyHeight + 40 + 'px';
            break;
          }
        }
      } catch (ex) {
        // Swallow exception
      }
    }
    );
  }

  /**
   * Initializes the listener.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attach context and settings for Qualtrics.
   */
  Drupal.behaviors.qualtrics_controller = {
    attach(context) {
      once("qualtrics_controller", "html").forEach((element) => {
        qualtrics_init();
      });
    },
  };
})(Drupal, once);
